#include <stdio.h>
#include <stdlib.h>

#include <time.h>

#include "utils/buffer.h"

#include "lexer.h"

int
main (int argc, char **argv)
{
	if (argc < 2)
		{
			fprintf (stderr, "usage: %s [filename]\n", argv[0]);
			return EXIT_FAILURE;
		}

	struct timespec ts1, ts2;
	clock_gettime (CLOCK_REALTIME, &ts1);

	struct buffer code = buffer_create ();
	if (!buffer_read (argv[1], &code))
		return EXIT_FAILURE;

	struct lexer lexer = lexer_create ();
	lexer_set_source (&code, &lexer);
	lexer_lex (&lexer);
	lexer_print (&lexer);

	lexer_free (&lexer);
	buffer_free (&code);

	clock_gettime (CLOCK_REALTIME, &ts2);
	unsigned long long ndiff = ts2.tv_nsec - ts1.tv_nsec;
	unsigned long long sdiff = ts2.tv_sec - ts1.tv_sec;

	printf ("it took %llu nanoseconds and %llu seconds to complete.\n", ndiff,
					sdiff);

	return EXIT_SUCCESS;
}
